package org.apache.bcel.generic;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Stream;
import org.apache.bcel.classfile.Annotations;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.classfile.ConstantValue;
import org.apache.bcel.classfile.Field;
import org.apache.bcel.classfile.Utility;
import org.apache.bcel.util.BCELComparator;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/FieldGen.class */
public class FieldGen extends FieldGenOrMethodGen {
    private static BCELComparator bcelComparator = new BCELComparator() { // from class: org.apache.bcel.generic.FieldGen.1
        public boolean equals(Object o1, Object o2) {
            FieldGen THIS = (FieldGen) o1;
            FieldGen THAT = (FieldGen) o2;
            return Objects.equals(THIS.getName(), THAT.getName()) && Objects.equals(THIS.getSignature(), THAT.getSignature());
        }

        public int hashCode(Object o) {
            FieldGen THIS = (FieldGen) o;
            return THIS.getSignature().hashCode() ^ THIS.getName().hashCode();
        }
    };
    private Object value;
    private List<FieldObserver> observers;

    public static BCELComparator getComparator() {
        return bcelComparator;
    }

    public static void setComparator(BCELComparator comparator) {
        bcelComparator = comparator;
    }

    public FieldGen(Field field, ConstantPoolGen cp) {
        this(field.getAccessFlags(), Type.getType(field.getSignature()), field.getName(), cp);
        for (ConstantValue constantValue : field.getAttributes()) {
            if (constantValue instanceof ConstantValue) {
                setValue(constantValue.getConstantValueIndex());
            } else if (constantValue instanceof Annotations) {
                Annotations runtimeAnnotations = (Annotations) constantValue;
                runtimeAnnotations.forEach(element -> {
                    addAnnotationEntry(new AnnotationEntryGen(element, cp, false));
                });
            } else {
                addAttribute(constantValue);
            }
        }
    }

    public FieldGen(int accessFlags, Type type, String name, ConstantPoolGen cp) {
        super(accessFlags);
        setType(type);
        setName(name);
        setConstantPool(cp);
    }

    private void addAnnotationsAsAttribute(ConstantPoolGen cp) {
        Stream.of((Object[]) AnnotationEntryGen.getAnnotationAttributes(cp, super.getAnnotationEntries())).forEach(this::addAttribute);
    }

    private int addConstant() {
        switch (super.getType().getType()) {
            case 4:
            case 5:
            case 8:
            case 9:
            case 10:
                return super.getConstantPool().addInteger(((Integer) this.value).intValue());
            case 6:
                return super.getConstantPool().addFloat(((Float) this.value).floatValue());
            case 7:
                return super.getConstantPool().addDouble(((Double) this.value).doubleValue());
            case 11:
                return super.getConstantPool().addLong(((Long) this.value).longValue());
            case 12:
            case 13:
            default:
                throw new IllegalStateException("Unhandled : " + ((int) super.getType().getType()));
            case 14:
                return super.getConstantPool().addString((String) this.value);
        }
    }

    public void addObserver(FieldObserver o) {
        if (this.observers == null) {
            this.observers = new ArrayList();
        }
        this.observers.add(o);
    }

    public void cancelInitValue() {
        this.value = null;
    }

    private void checkType(Type atype) {
        Type superType = super.getType();
        if (superType == null) {
            throw new ClassGenException("You haven't defined the type of the field yet");
        }
        if (!isFinal()) {
            throw new ClassGenException("Only final fields may have an initial value!");
        }
        if (!superType.equals(atype)) {
            throw new ClassGenException("Types are not compatible: " + superType + " vs. " + atype);
        }
    }

    public FieldGen copy(ConstantPoolGen cp) {
        FieldGen fg = (FieldGen) clone();
        fg.setConstantPool(cp);
        return fg;
    }

    public boolean equals(Object obj) {
        return bcelComparator.equals(this, obj);
    }

    public Field getField() {
        String signature = getSignature();
        int nameIndex = super.getConstantPool().addUtf8(super.getName());
        int signatureIndex = super.getConstantPool().addUtf8(signature);
        if (this.value != null) {
            checkType(super.getType());
            int index = addConstant();
            addAttribute(new ConstantValue(super.getConstantPool().addUtf8("ConstantValue"), 2, index, super.getConstantPool().getConstantPool()));
        }
        addAnnotationsAsAttribute(super.getConstantPool());
        return new Field(super.getAccessFlags(), nameIndex, signatureIndex, getAttributes(), super.getConstantPool().getConstantPool());
    }

    public String getInitValue() {
        if (this.value != null) {
            return this.value.toString();
        }
        return null;
    }

    @Override // org.apache.bcel.generic.FieldGenOrMethodGen
    public String getSignature() {
        return super.getType().getSignature();
    }

    public int hashCode() {
        return bcelComparator.hashCode(this);
    }

    public void removeObserver(FieldObserver o) {
        if (this.observers != null) {
            this.observers.remove(o);
        }
    }

    public void setInitValue(boolean b) {
        checkType(Type.BOOLEAN);
        if (b) {
            this.value = 1;
        }
    }

    public void setInitValue(byte b) {
        checkType(Type.BYTE);
        if (b != 0) {
            this.value = Integer.valueOf(b);
        }
    }

    public void setInitValue(char c) {
        checkType(Type.CHAR);
        if (c != 0) {
            this.value = Integer.valueOf(c);
        }
    }

    public void setInitValue(double d) {
        checkType(Type.DOUBLE);
        if (d != 0.0d) {
            this.value = Double.valueOf(d);
        }
    }

    public void setInitValue(float f) {
        checkType(Type.FLOAT);
        if (f != 0.0d) {
            this.value = Float.valueOf(f);
        }
    }

    public void setInitValue(int i) {
        checkType(Type.INT);
        if (i != 0) {
            this.value = Integer.valueOf(i);
        }
    }

    public void setInitValue(long l) {
        checkType(Type.LONG);
        if (l != 0) {
            this.value = Long.valueOf(l);
        }
    }

    public void setInitValue(short s) {
        checkType(Type.SHORT);
        if (s != 0) {
            this.value = Integer.valueOf(s);
        }
    }

    public void setInitValue(String str) {
        checkType(ObjectType.getInstance("java.lang.String"));
        if (str != null) {
            this.value = str;
        }
    }

    private void setValue(int index) {
        ConstantPool cp = super.getConstantPool().getConstantPool();
        this.value = cp.getConstant(index).getConstantValue(cp);
    }

    public final String toString() {
        String access = Utility.accessToString(super.getAccessFlags());
        String access2 = access.isEmpty() ? "" : access + " ";
        String signature = super.getType().toString();
        String name = getName();
        StringBuilder buf = new StringBuilder(32);
        buf.append(access2).append(signature).append(" ").append(name);
        String value = getInitValue();
        if (value != null) {
            buf.append(" = ").append(value);
        }
        return buf.toString();
    }

    public void update() {
        if (this.observers != null) {
            for (FieldObserver observer : this.observers) {
                observer.notify(this);
            }
        }
    }
}
